@@ -1,12 +1,18 @@
 #' @importFrom magrittr "%>%"
 #' @importFrom tibble tibble
 #' @importFrom httr GET
+#' @importFrom sf st_as_sf
 #' @importFrom lubridate parse_date_time
 #' @importFrom xml2 read_xml
+#' @importFrom xml2 as_list
+#' @importFrom xml2 xml_contents
 #' @importFrom xml2 xml_text
 #' @importFrom xml2 xml_find_all
 #' @importFrom xml2 xml_find_first
 #' @importFrom dplyr select
+#' @importFrom dplyr full_join
+#' @importFrom stringr str_extract
+#' @importFrom purrr map
 #' @author Robert Myles McDonnell, \email{robertmylesmcdonnell@gmail.com}
 #' @references \url{https://en.wikipedia.org/wiki/RSS}
 #' @title Extract a tidy data frame from RSS and Atom and JSON feeds
@@ -14,6 +20,10 @@
 #' produces a tidy data frame, easy to use for further manipulation and
 #' analysis.
 #' @param feed (\code{character}). The url for the feed that you want to parse.
+#' @param sf (\code{logical}). By default, \code{tidyfeed()} returns a simple
+#' features dataframe from georss feeds. This behaviour can be changed by setting
+#' \code{sf = FALSE}, which will return a dataframe that includes a column for
+#' latitude and a column for longitude.
 #' @examples
 #' \dontrun{
 #' # Atom feed:
@@ -22,9 +32,11 @@
 #' tidyfeed("http://fivethirtyeight.com/all/feed")
 #' # jsonfeed:
 #' tidyfeed("https://daringfireball.net/feeds/json")
+#' # georss:
+#' tidyfeed("http://www.geonames.org/recent-changes.xml")
 #' }
 #' @export
-tidyfeed <- function(feed){
+tidyfeed <- function(feed, sf = TRUE){
   invisible({
   suppressWarnings({
   stopifnot(identical(length(feed), 1L)) # exit if more than 1 feed provided
@@ -51,6 +63,17 @@ tidyfeed <- function(feed){
 
     return(result)
 
+  } else if(grepl("http://www.georss.org/georss", xml2::xml_attr(doc, "xmlns:georss"))){
+
+    result <- geo_parse(doc)
+
+    if(sf == TRUE){
+      result <- sf::st_as_sf(x = result, coords = c("item_long", "item_lat"),
+                             crs = "+proj=longlat +datum=WGS84")
+    }
+
+    return(result)
+
   } else{
     result <- rss_parse(doc)
 
