@@ -7,7 +7,7 @@ test_that("tidyfeed returns an error when it should", {
 
 test_that("tidyfeed returns a data_frame", {
   data("feeds")
-  rss <- sample(feeds$feeds, 1)
+  rss <- "http://fivethirtyeight.com/all/feed"
   expect_is(tidyfeed(rss), "tbl_df")
 })
 
